import * as _nuxt_schema from '@nuxt/schema';
import { PluginOptions } from 'anu-vue';

/** Nuxt Module Options */
interface PresetThemeOptions {
    /**
     * Import Anu Preset Theme with either CSS or SASS
     * You can either import CSS which doesn't require any additional setup
     * or SASS which requires you to install `sass` dependencies.
     *
     * @default 'css'
     */
    style?: 'css' | 'scss';
}
interface ModuleOptions {
    /**
     * Import Anu Preset Theme Default | Source npm pkg: `@anu-vue/preset-theme-default`
     * When enabled, it will automatically set up the default presets for Anu and Uno.
     * We recommend to enable this option to get the best experience.
     *
     * @default true
     */
    presetTheme?: PresetThemeOptions | boolean;
    /**
     * Anu Vue Initial Theme | Source npm pkg: `anu-vue`
     * You can pass in your own initial theme to override the default theme.
     *
     * @remarks
     * The default theme for `initialTheme` is `light`. You can also make it `dark` by setting it to `dark`.
     *
     * @default 'light'
     */
    initialTheme?: PluginOptions['initialTheme'];
    /**
     * Anu Vue Themes | Source npm pkg: `anu-vue`
     * You can pass in your own themes to override the default themes.
     *
     * @remarks
     * The default themes for `light` and `dark` are:
     *
     * ```ts
     * {
     *   light: {
     *     class: '',
     *     colors: {
     *       primary: '265, 97.7%, 66.3%',
     *       success: '94.5, 100%, 39.6%',
     *       info: '200.1, 100%, 54.3%',
     *       warning: '42.4, 100%, 50%',
     *       danger: '358.3, 100%, 64.9%',
     *     },
     *     cssVars: {},
     *   },
     *   dark: {
     *     class: 'dark',
     *     colors: {
     *       primary: '261, 73%, 66.3%',
     *       success: '94.5, 73%, 39.6%',
     *       info: '200.1, 73%, 54.3%',
     *       warning: '42.4, 73%, 50%',
     *       danger: '358.3, 73%, 64.9%',
     *     },
     *     cssVars: {},
     *   },
     * }
     * ```
     */
    themes?: PluginOptions['themes'];
}
declare const _default: _nuxt_schema.NuxtModule<ModuleOptions>;

declare module '@nuxt/schema' {
    interface NuxtConfig {
        anu?: ModuleOptions;
    }
    interface NuxtOptions {
        anu?: ModuleOptions;
    }
}

export { ModuleOptions, _default as default };
